summaryrefslogtreecommitdiff
path: root/amiga/ctxmenu.h
diff options
context:
space:
mode:
authorChris Young <chris@unsatisfactorysoftware.co.uk>2015-09-05 01:41:56 +0100
committerChris Young <chris@unsatisfactorysoftware.co.uk>2015-09-05 01:41:56 +0100
commit00aa1e2d3501ee0a004415a56a845db51c660ef4 (patch)
tree3b19a99984a692e1b5641ebe6265bdbcff018901 /amiga/ctxmenu.h
parent46f3670fae57fb1b05a1d8304f500b0ac3350b16 (diff)
downloadnetsurf-00aa1e2d3501ee0a004415a56a845db51c660ef4.tar.gz
netsurf-00aa1e2d3501ee0a004415a56a845db51c660ef4.tar.bz2
Add a small test menu to the clicktab gadget
Diffstat (limited to 'amiga/ctxmenu.h')
-rw-r--r--amiga/ctxmenu.h11
1 files changed, 10 insertions, 1 deletions
diff --git a/amiga/ctxmenu.h b/amiga/ctxmenu.h
index 15009d3b0..79c0dc793 100644
--- a/amiga/ctxmenu.h
+++ b/amiga/ctxmenu.h
@@ -62,7 +62,7 @@ void ami_ctxmenu_release_hook(struct Hook *hook);
* Create history context menu
* The first time this is run it will create an empty menu,
* Subsequent runs will (re-)populate with the history.
* This is to allow the pointer to be obtained before the browser_winodw is opened.
*
* \param direction AMI_CTXMENU_HISTORY_(BACK|FORWARD)
* \param gwin struct gui_window_2 *
@@ -71,6 +71,15 @@ void ami_ctxmenu_release_hook(struct Hook *hook);
*/
struct Menu *ami_ctxmenu_history_create(int direction, struct gui_window_2 *gwin);
+/**
+ * Create ClickTab context menu
+ *
+ * \param gwin struct gui_window_2 *
+ * \returns pointer to menu (for convenience, is also stored in gwin structure)
+ * The returned pointer MUST be disposed of with DisposeObject before program exit.
+ */
+struct Menu *ami_ctxmenu_clicktab_create(struct gui_window_2 *gwin);
+
#else
inline void ami_ctxmenu_init(void) {}
inline void ami_ctxmenu_free(void) {}
@@ -62,7 +62,7 @@ void ami_ctxmenu_release_hook(struct Hook *hook);
* The first time this is run it will create an empty menu,
* Subsequent runs will (re-)populate with the history.
- * This is to allow the pointer to be obtained before the browser_winodw is opened.
+ * This is to allow the pointer to be obtained before the browser_window is opened.
*
* \param direction AMI_CTXMENU_HISTORY_(BACK|FORWARD)